Class: Google::Cloud::CommerceProducer::V1beta::ListPrivateOfferDocumentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for requesting list of PrivateOfferDocuments

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.

Returns:

  • (::Integer)

    Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.



228
229
230
231
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 228

class ListPrivateOfferDocumentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.

When paginating, all other parameters of the list request must match the request that returned the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.

    When paginating, all other parameters of the list request must match the request that returned the page token.



228
229
230
231
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 228

class ListPrivateOfferDocumentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListPrivateOfferDocumentsRequest.

Returns:

  • (::String)

    Required. Parent value for ListPrivateOfferDocumentsRequest.



228
229
230
231
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 228

class ListPrivateOfferDocumentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end