Class: Google::Cloud::CommerceProducer::V1beta::ListPrivateOfferDocumentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for response to listing PrivateOfferDocuments

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



241
242
243
244
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 241

class ListPrivateOfferDocumentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_offer_documents::Array<::Google::Cloud::CommerceProducer::V1beta::PrivateOfferDocument>

Returns The list of PrivateOfferDocuments.

Returns:



241
242
243
244
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 241

class ListPrivateOfferDocumentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end