Class: Google::Cloud::CommerceProducer::V1beta::ListPrivateOffersRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::ListPrivateOffersRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for requesting list of PrivateOffers
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter expression that matches a subset of resources to show. See https://google.aip.dev/160 for more details. Only supports filtering by:
update_time. Example:update_time > "2012-04-21T11:30:00-04:00".
55 56 57 58 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 55 class ListPrivateOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Ordering expression for sorting the results. See https://google.aip.dev/132#ordering for more details. If no value is present the default ordering is unspecified. Only supports ordering by:
update_time.
55 56 57 58 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 55 class ListPrivateOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.
55 56 57 58 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 55 class ListPrivateOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.
When paginating, all other parameters of the list request must match the request that returned the page token.
55 56 57 58 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 55 class ListPrivateOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for ListPrivateOffersRequest.
55 56 57 58 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 55 class ListPrivateOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |