Class: Google::Cloud::CommerceProducer::V1beta::ListServicesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for requesting list of Services

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.

Returns:

  • (::Integer)

    Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.



304
305
306
307
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 304

class ListServicesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



304
305
306
307
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 304

class ListServicesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListServicesRequest.

Returns:

  • (::String)

    Required. Parent value for ListServicesRequest



304
305
306
307
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 304

class ListServicesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end