Class: Google::Cloud::CommerceProducer::V1beta::ListServicesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for response to listing Services

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



317
318
319
320
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 317

class ListServicesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#services::Array<::Google::Cloud::CommerceProducer::V1beta::Service>

Returns The list of Service.

Returns:



317
318
319
320
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 317

class ListServicesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end