Class: Google::Cloud::CommerceProducer::V1beta::ListSkuGroupsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for response to listing SkuGroups

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



481
482
483
484
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 481

class ListSkuGroupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sku_groups::Array<::Google::Cloud::CommerceProducer::V1beta::SkuGroup>

Returns The list of SkuGroup.

Returns:



481
482
483
484
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 481

class ListSkuGroupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end