Class: Google::Cloud::CommerceProducer::V1beta::ListSkusResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::ListSkusResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for response to listing Skus
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#skus ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::Sku>
The list of Sku.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
429 430 431 432 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 429 class ListSkusResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skus ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::Sku>
Returns The list of Sku.
429 430 431 432 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 429 class ListSkusResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |