Class: Google::Cloud::CommerceProducer::V1beta::ListStandardOffersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for requesting list of StandardOffers

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter expression that matches a subset of resources to show. See https://google.aip.dev/160 for more details. Supports filtering by:

  • effective_time. Example: effective_time > "2012-04-21T11:30:00-04:00".
  • expire_time. Example: expire_time < "2026-05-06T00:00:00Z".

Returns:

  • (::String)

    Optional. Filter expression that matches a subset of resources to show. See https://google.aip.dev/160 for more details. Supports filtering by:

    • effective_time. Example: effective_time > "2012-04-21T11:30:00-04:00".
    • expire_time. Example: expire_time < "2026-05-06T00:00:00Z".


369
370
371
372
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 369

class ListStandardOffersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Ordering expression for sorting the results. See https://google.aip.dev/132#ordering for more details. If no value is present the default ordering is unspecified. Supports ordering by:

  • effective_time
  • expire_time.

Returns:

  • (::String)

    Optional. Ordering expression for sorting the results. See https://google.aip.dev/132#ordering for more details. If no value is present the default ordering is unspecified. Supports ordering by:

    • effective_time
    • expire_time


369
370
371
372
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 369

class ListStandardOffersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.

Returns:

  • (::Integer)

    Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.



369
370
371
372
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 369

class ListStandardOffersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.

When paginating, all other parameters of the list request must match the request that returned the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.

    When paginating, all other parameters of the list request must match the request that returned the page token.



369
370
371
372
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 369

class ListStandardOffersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListStandardOffersRequest.

Returns:

  • (::String)

    Required. Parent value for ListStandardOffersRequest



369
370
371
372
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 369

class ListStandardOffersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end