Class: Google::Cloud::CommerceProducer::V1beta::ListStandardOffersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::ListStandardOffersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for response to listing StandardOffers
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#standard_offers ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::StandardOffer>
The list of StandardOffer.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
382 383 384 385 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 382 class ListStandardOffersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#standard_offers ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::StandardOffer>
Returns The list of StandardOffer.
382 383 384 385 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 382 class ListStandardOffersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |