Class: Google::Cloud::CommerceProducer::V1beta::PrivateOffer::PartnerContact

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb

Overview

Contact information for the partner representative.

Instance Attribute Summary collapse

Instance Attribute Details

#contact::String

Returns Optional. Display text identifying the partner sales contact. Displayed to the customer. Must be provided when publishing the offer. Maximum length: 256 characters.

Returns:

  • (::String)

    Optional. Display text identifying the partner sales contact. Displayed to the customer. Must be provided when publishing the offer. Maximum length: 256 characters.



187
188
189
190
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 187

class PartnerContact
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#email::String

Returns Optional. The email address of the partner sales contact. Displayed to the customer. The format of the provided email address is validated when publishing the offer, but no verification is performed that the email address actually exists, accepts email, or is otherwise functional.

Returns:

  • (::String)

    Optional. The email address of the partner sales contact. Displayed to the customer. The format of the provided email address is validated when publishing the offer, but no verification is performed that the email address actually exists, accepts email, or is otherwise functional.



187
188
189
190
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 187

class PartnerContact
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end