Module: Google::Cloud::CommerceProducer::V1beta::PrivateOffer::Term::StartPolicy

Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb

Overview

Defines when an offer should start.

Constant Summary collapse

START_POLICY_UNSPECIFIED =

Default value. This value is unused.

0
IMMEDIATE =

The resulting order starts immediately upon the customer's acceptance of the offer, if no partner approval is required, or else immediately after the partner approves the purchase if order approval is required. This enum value cannot be combined with term.scheduled_start_time.

1
SCHEDULED_START_TIME =

The resulting order starts at the scheduled start time.

2