Class: Google::Cloud::CommerceProducer::V1beta::PrivateOfferDocument

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb

Overview

Message describing the PrivateOfferDocument resource. Used to attach documents to a private offer in state DRAFT. Once a private offer is no longer in state DRAFT, the set of child documents is immutable. Existing documents cannot be updated or deleted, and new documents cannot be added.

A private offer must include a EULA, either by assigning a standard EULA or attaching a custom EULA document, or a statement of work document.

Defined Under Namespace

Modules: DocumentType

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The creation time of the resource.

Returns:



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end

#document_type::Google::Cloud::CommerceProducer::V1beta::PrivateOfferDocument::DocumentType

Returns Required. The classification type of the document. Used to distinguish between different types of documents that may be attached to a private offer for different business purposes.

Returns:



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end

#inline_content::String

Returns Optional. Byte content of an unstructured document. Max size: 4MB.

Returns:

  • (::String)

    Optional. Byte content of an unstructured document. Max size: 4MB



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end

#mime_type::String

Returns Optional. The MIME type of the document. Used to distinguish between different document formats. Supported formats (which may be expanded in the future)

  • 'application/pdf'.

Returns:

  • (::String)

    Optional. The MIME type of the document. Used to distinguish between different document formats. Supported formats (which may be expanded in the future)

    • 'application/pdf'


1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end

#name::String

Returns Identifier. Name of the resource.

Returns:

  • (::String)

    Identifier. Name of the resource.



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The last update time of the resource.

Returns:



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 1086

class PrivateOfferDocument
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Supported types of documents.
  # Additional document types may be added in future. Further editions of the
  # Google Cloud Marketplace Standard EULA may be published in future, which
  # may result in changes to the subset of Standard EULA versions permitted
  # to be used in new offers.
  module DocumentType
    # The default / unset value. Do not use.
    DOCUMENT_TYPE_UNSPECIFIED = 0

    # The document is a custom EULA used in place of the standard product EULA.
    # A private offer may not have more than one custom EULA document.
    #
    # If this enum value is set, then mime_type and inline_content must
    # be set.
    CUSTOM_END_USER_LICENSE_AGREEMENT = 1

    # The document is the statement of work required by the [Cloud Marketplace
    # Product Specific
    # Terms](https://cloud.google.com/terms/marketplace-product-terms) for all
    # Professional Services product private offers.
    # This document type is not permitted for private offers of any other
    # product type.
    # A private offer may not have more than one statement of work document.
    #
    # The mime_type and inline_content fields must be set.
    STATEMENT_OF_WORK = 2

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v1-12102020.
    # Existing offers may have this document type, but this is not permitted
    # for new offers.
    STANDARD_END_USER_LICENSE_AGREEMENT_V1 = 3

    # The document is the Marketplace standard EULA, with the following link:
    # https://cloud.google.com/terms/marketplace/eula-standard-v2-01272021
    #
    # New offers using Standard EULAs should set this enum value. This is not
    # permitted for Professional Services products.
    #
    # The mime_type and inline_content fields must not be set.
    STANDARD_END_USER_LICENSE_AGREEMENT_V2 = 4
  end
end