Class: Google::Cloud::CommerceProducer::V1beta::ResolveAmendmentTargetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for resolving an amended offer.

Instance Attribute Summary collapse

Instance Attribute Details

#base_standard_offer::String

Returns Required. The base standard offer that the private offer will be based on. Format: projects/{project}/locations/{location}/services/{service}/standardOffers/{standard_offer}.

Returns:

  • (::String)

    Required. The base standard offer that the private offer will be based on. Format: projects/{project}/locations/{location}/services/{service}/standardOffers/{standard_offer}.



100
101
102
103
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 100

class ResolveAmendmentTargetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ResolveAmendmentTargetRequest.

Returns:

  • (::String)

    Required. Parent value for ResolveAmendmentTargetRequest



100
101
102
103
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 100

class ResolveAmendmentTargetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_billing_account::String

Returns Required. The customer's billing account targeted by the offer. This is the billing account for which the new private offer will be created on. Format: billingAccounts/{billing_account}.

Returns:

  • (::String)

    Required. The customer's billing account targeted by the offer. This is the billing account for which the new private offer will be created on. Format: billingAccounts/{billing_account}.



100
101
102
103
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 100

class ResolveAmendmentTargetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end