Class: Google::Cloud::CommerceProducer::V1beta::ResolveAmendmentTargetResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message in response to ResolveAmendmentTarget.

Defined Under Namespace

Classes: OptionalOffers

Instance Attribute Summary collapse

Instance Attribute Details

#optional_offers::Google::Cloud::CommerceProducer::V1beta::ResolveAmendmentTargetResponse::OptionalOffers

Returns A list of existing offers that may optionally be amended.

Note: The following fields are mutually exclusive: optional_offers, required_private_offer, required_standard_offer. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 127

class ResolveAmendmentTargetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A wrapper message containing offers that can optionally be amended.
  # @!attribute [rw] private_offers
  #   @return [::Array<::String>]
  #     A list of existing private offers that are eligible to be amended.
  #
  #     When creating a new private offer, the client may choose to populate the
  #     `single_product_offer.amended_private_offer` field with one of these
  #     resource names. Alternatively, the client may leave the field unset to
  #     create a brand new offer.
  class OptionalOffers
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#required_private_offer::String

Returns The resource name of an existing private offer that MUST be amended.

If this is set, the new private offer the client creates must populate the single_product_offer.amended_private_offer field with this value.

Note: The following fields are mutually exclusive: required_private_offer, required_standard_offer, optional_offers. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The resource name of an existing private offer that MUST be amended.

    If this is set, the new private offer the client creates must populate the single_product_offer.amended_private_offer field with this value.

    Note: The following fields are mutually exclusive: required_private_offer, required_standard_offer, optional_offers. If a field in that set is populated, all other fields in the set will automatically be cleared.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 127

class ResolveAmendmentTargetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A wrapper message containing offers that can optionally be amended.
  # @!attribute [rw] private_offers
  #   @return [::Array<::String>]
  #     A list of existing private offers that are eligible to be amended.
  #
  #     When creating a new private offer, the client may choose to populate the
  #     `single_product_offer.amended_private_offer` field with one of these
  #     resource names. Alternatively, the client may leave the field unset to
  #     create a brand new offer.
  class OptionalOffers
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#required_standard_offer::String

Returns The resource name of an existing standard offer that MUST be amended.

If this is set, the new private offer the client creates must populate the single_product_offer.amended_standard_offer field with this value.

Note: The following fields are mutually exclusive: required_standard_offer, required_private_offer, optional_offers. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The resource name of an existing standard offer that MUST be amended.

    If this is set, the new private offer the client creates must populate the single_product_offer.amended_standard_offer field with this value.

    Note: The following fields are mutually exclusive: required_standard_offer, required_private_offer, optional_offers. If a field in that set is populated, all other fields in the set will automatically be cleared.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 127

class ResolveAmendmentTargetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A wrapper message containing offers that can optionally be amended.
  # @!attribute [rw] private_offers
  #   @return [::Array<::String>]
  #     A list of existing private offers that are eligible to be amended.
  #
  #     When creating a new private offer, the client may choose to populate the
  #     `single_product_offer.amended_private_offer` field with one of these
  #     resource names. Alternatively, the client may leave the field unset to
  #     create a brand new offer.
  class OptionalOffers
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end