Class: Google::Cloud::CommerceProducer::V1beta::ResolveAmendmentTargetResponse::OptionalOffers

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

A wrapper message containing offers that can optionally be amended.

Instance Attribute Summary collapse

Instance Attribute Details

#private_offers::Array<::String>

Returns A list of existing private offers that are eligible to be amended.

When creating a new private offer, the client may choose to populate the single_product_offer.amended_private_offer field with one of these resource names. Alternatively, the client may leave the field unset to create a brand new offer.

Returns:

  • (::Array<::String>)

    A list of existing private offers that are eligible to be amended.

    When creating a new private offer, the client may choose to populate the single_product_offer.amended_private_offer field with one of these resource names. Alternatively, the client may leave the field unset to create a brand new offer.



140
141
142
143
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 140

class OptionalOffers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end