Module: Google::Cloud::CommerceProducer::V1beta::ServiceView

Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Controls which fields are returned in a Service returned by the API. https://google.aip.dev/157

Constant Summary collapse

SERVICE_VIEW_UNSPECIFIED =

The default / unset value. The API will default to the BASIC view.

0
SERVICE_VIEW_BASIC =

Include basic metadata about the Service, but not the full contents. This is the default value (for both List and Get requests).

1
SERVICE_VIEW_FULL =

Include everything.

2