Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformDeployedModelUsageFee

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Details about a SKU pricing usage of an AI Platform Self Deployed Model.

Defined Under Namespace

Modules: UsageCalculation

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_type::String (readonly)

Returns Output only. The SKU applies to a specific accelerator type. Contains the name of the matching AI Platform AcceleratorType. The corresponding linear scaling value is the dimensionless accelerator_count.

Returns:



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 647

class AiPlatformDeployedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines how the customer's usage is calculated.
  module UsageCalculation
    # Unused.
    USAGE_CALCULATION_UNSPECIFIED = 0

    # Usage is calculated from deployment runtime and size.
    # Usage is calculated by measuring the deployment runtime in hours and
    # multiplying by the amount of the deployed model's hardware resource
    # matching the SKU's hardware resource type.
    # This results in a composite `unit` of hours ('h') multiplied by the
    # unit that denominates the hardware resource, though note that
    # multiplying by the dimensionless unit ("1") has no effect.
    LINEAR_RESOURCE_SCALED_DEPLOYMENT_RUNTIME = 2
  end
end

#price_per_unit::Google::Type::Money (readonly)

Returns Output only. The price per unit of usage. The customer's usage charge is computed by measuring the customer's consumption denominated in price units and multiplying by this price.

Returns:

  • (::Google::Type::Money)

    Output only. The price per unit of usage. The customer's usage charge is computed by measuring the customer's consumption denominated in price units and multiplying by this price.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 647

class AiPlatformDeployedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines how the customer's usage is calculated.
  module UsageCalculation
    # Unused.
    USAGE_CALCULATION_UNSPECIFIED = 0

    # Usage is calculated from deployment runtime and size.
    # Usage is calculated by measuring the deployment runtime in hours and
    # multiplying by the amount of the deployed model's hardware resource
    # matching the SKU's hardware resource type.
    # This results in a composite `unit` of hours ('h') multiplied by the
    # unit that denominates the hardware resource, though note that
    # multiplying by the dimensionless unit ("1") has no effect.
    LINEAR_RESOURCE_SCALED_DEPLOYMENT_RUNTIME = 2
  end
end

#unit::String (readonly)

Returns Output only. The price unit of the SKU. See https://ucum.org/ucum.html for the format of the price unit. Currently the unit is always hours ('h'). This may change in future.

Returns:

  • (::String)

    Output only. The price unit of the SKU. See https://ucum.org/ucum.html for the format of the price unit. Currently the unit is always hours ('h'). This may change in future.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 647

class AiPlatformDeployedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines how the customer's usage is calculated.
  module UsageCalculation
    # Unused.
    USAGE_CALCULATION_UNSPECIFIED = 0

    # Usage is calculated from deployment runtime and size.
    # Usage is calculated by measuring the deployment runtime in hours and
    # multiplying by the amount of the deployed model's hardware resource
    # matching the SKU's hardware resource type.
    # This results in a composite `unit` of hours ('h') multiplied by the
    # unit that denominates the hardware resource, though note that
    # multiplying by the dimensionless unit ("1") has no effect.
    LINEAR_RESOURCE_SCALED_DEPLOYMENT_RUNTIME = 2
  end
end

#usage_calculation::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformDeployedModelUsageFee::UsageCalculation (readonly)

Returns Output only. Determines how the customer's usage is calculated.

Returns:



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 647

class AiPlatformDeployedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines how the customer's usage is calculated.
  module UsageCalculation
    # Unused.
    USAGE_CALCULATION_UNSPECIFIED = 0

    # Usage is calculated from deployment runtime and size.
    # Usage is calculated by measuring the deployment runtime in hours and
    # multiplying by the amount of the deployed model's hardware resource
    # matching the SKU's hardware resource type.
    # This results in a composite `unit` of hours ('h') multiplied by the
    # unit that denominates the hardware resource, though note that
    # multiplying by the dimensionless unit ("1") has no effect.
    LINEAR_RESOURCE_SCALED_DEPLOYMENT_RUNTIME = 2
  end
end