Module: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformDeployedModelUsageFee::UsageCalculation

Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Determines how the customer's usage is calculated.

Constant Summary collapse

USAGE_CALCULATION_UNSPECIFIED =

Unused.

0
LINEAR_RESOURCE_SCALED_DEPLOYMENT_RUNTIME =

Usage is calculated from deployment runtime and size. Usage is calculated by measuring the deployment runtime in hours and multiplying by the amount of the deployed model's hardware resource matching the SKU's hardware resource type. This results in a composite unit of hours ('h') multiplied by the unit that denominates the hardware resource, though note that multiplying by the dimensionless unit ("1") has no effect.

2