Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelEndpointLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Location scope for a SKU that applies to an AI Platform Managed Model endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#global_endpoint::Boolean (readonly)

Returns Output only. The SKU applies to a global endpoint. Note: This is distinct from the conventional meaning of "global" as a SKU that applies to all locations.

Note: The following fields are mutually exclusive: global_endpoint, region_id, multi_region_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Output only. The SKU applies to a global endpoint. Note: This is distinct from the conventional meaning of "global" as a SKU that applies to all locations.

    Note: The following fields are mutually exclusive: global_endpoint, region_id, multi_region_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



785
786
787
788
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 785

class AiPlatformManagedModelEndpointLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#multi_region_id::String (readonly)

Returns Output only. The SKU applies to a multi-region.

Note: The following fields are mutually exclusive: multi_region_id, region_id, global_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Output only. The SKU applies to a multi-region.

    Note: The following fields are mutually exclusive: multi_region_id, region_id, global_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.



785
786
787
788
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 785

class AiPlatformManagedModelEndpointLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region_id::String (readonly)

Returns Output only. The SKU applies to a region.

Note: The following fields are mutually exclusive: region_id, global_endpoint, multi_region_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Output only. The SKU applies to a region.

    Note: The following fields are mutually exclusive: region_id, global_endpoint, multi_region_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



785
786
787
788
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 785

class AiPlatformManagedModelEndpointLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end