Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Details about a SKU pricing usage of an AI Platform Managed Model (MaaS).

Defined Under Namespace

Modules: PredictionMode Classes: AiPlatformManagedModelUsageMetric, CombinedRequestInputTokensRange, ProvisionedThroughputOverage

Instance Attribute Summary collapse

Instance Attribute Details

#combined_request_input_tokens_range::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::CombinedRequestInputTokensRange (readonly)

Returns Output only. The range of aggregated input token values covered by the SKU. Unset if the SKU is not scoped to a particular range. A request is in scope for this SKU if its aggregated input token value falls within the range. The collection of SKUs in effect at any given time scoped to a particular aggregated input token value range will cover all possible values without overlap. Such a collection of SKUs form a "tiered" price structure over the possible value, with each SKU acting as a "tier".

NOTE: This is distinct from a SKU with tiered pricing.

Returns:

  • (::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::CombinedRequestInputTokensRange)

    Output only. The range of aggregated input token values covered by the SKU. Unset if the SKU is not scoped to a particular range. A request is in scope for this SKU if its aggregated input token value falls within the range. The collection of SKUs in effect at any given time scoped to a particular aggregated input token value range will cover all possible values without overlap. Such a collection of SKUs form a "tiered" price structure over the possible value, with each SKU acting as a "tier".

    NOTE: This is distinct from a SKU with tiered pricing.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end

#location::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelEndpointLocation (readonly)

Returns Output only. The model endpoint location where usage is priced by this SKU. If no location is specified, the SKU applies to usage in all locations.

Returns:



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end

#prediction_mode::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::PredictionMode (readonly)

Returns Output only. The prediction mode of requests that the SKU applies to.

Returns:



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end

#provisioned_throughput_overage::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::ProvisionedThroughputOverage (readonly)

Returns Output only. Set when the SKU is a historical provisioned throughput overage SKU. Starting 2025-08-26 such SKUs have no effect, and usage in excess of provisioned throughput quota is now metered as standard usage. This field is set only in historical SKU timeline entries for overage SKUs belonging to partners that offered provisioned throughput for AI Platform managed model products prior to the unification of standard usage and provisioned throughput overage metering.

Returns:

  • (::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::ProvisionedThroughputOverage)

    Output only. Set when the SKU is a historical provisioned throughput overage SKU. Starting 2025-08-26 such SKUs have no effect, and usage in excess of provisioned throughput quota is now metered as standard usage. This field is set only in historical SKU timeline entries for overage SKUs belonging to partners that offered provisioned throughput for AI Platform managed model products prior to the unification of standard usage and provisioned throughput overage metering.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end

#tiered_price::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::TieredPrice (readonly)

Returns Output only. Tiered pricing of the SKU.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end

#usage_metric::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric (readonly)

Returns Output only. The usage metric that the SKU applies to.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 458

class AiPlatformManagedModelUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The usage metric that the SKU applies to.
  # @!attribute [r] input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric]
  #     Output only. Input tokens read from the prediction endpoint input.
  #
  #     Note: The following fields are mutually exclusive: `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_read_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric]
  #     Output only. Input tokens read from the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_read_input_tokens_metric`, `input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] cache_write_input_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric]
  #     Output only. Input tokens written to the cache.
  #
  #     Note: The following fields are mutually exclusive: `cache_write_input_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `output_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] output_tokens_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric]
  #     Output only. Output tokens returned from the prediction endpoint.
  #
  #     Note: The following fields are mutually exclusive: `output_tokens_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `web_search_requests_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] web_search_requests_metric
  #   @return [::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric]
  #     Output only. Web search requests executed by the model.
  #
  #     Note: The following fields are mutually exclusive: `web_search_requests_metric`, `input_tokens_metric`, `cache_read_input_tokens_metric`, `cache_write_input_tokens_metric`, `output_tokens_metric`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AiPlatformManagedModelUsageMetric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Input tokens read from the input to the prediction endpoint.
    # The unit for this metric is dimensionless.
    class InputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens read from the cache.
    # The unit for this metric is dimensionless.
    class CacheReadInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Input tokens written to the cache.
    # The unit for this metric is dimensionless.
    # @!attribute [r] ttl
    #   @return [::Google::Protobuf::Duration]
    #     Output only. The duration the write is retained in the cache.
    class CacheWriteInputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Output tokens returned from the prediction endpoint.
    # The unit for this metric is dimensionless.
    class OutputTokensMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Web search requests executed by the model.
    # The unit for this metric is dimensionless.
    class WebSearchRequestsMetric
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The range of aggregated input token values covered by the SKU.
  #
  # A request to a managed model has an aggregated input token value
  # determined by the sum of the metric values of the input token metrics.
  #
  # * input tokens
  # * cache read input tokens
  # * cache write input tokens
  # @!attribute [r] start_value
  #   @return [::Integer]
  #     Output only. The inclusive lower bound of the range.
  # @!attribute [r] end_value
  #   @return [::Integer]
  #     Output only. The exclusive upper bound of the range.
  #     If no end value is specified, the range is unbounded from above.
  class CombinedRequestInputTokensRange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Additional details present for historical provisioned throughput
  # "overage" SKUs that applied charges only to usage above the customer's
  # provisioned throughput quota threshold.
  # @!attribute [r] service
  #   @return [::String]
  #     Output only. The service whose usage the overage SKU applied to.
  class ProvisionedThroughputOverage
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The prediction modes of requests that the SKU applies to.
  module PredictionMode
    # The SKU does not distinguish between prediction modes.
    PREDICTION_MODE_UNSPECIFIED = 0

    # The SKU applies to online prediction.
    ONLINE_PREDICTION = 1

    # The SKU applies to batch prediction.
    BATCH_PREDICTION = 2
  end
end