Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::CombinedRequestInputTokensRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

The range of aggregated input token values covered by the SKU.

A request to a managed model has an aggregated input token value determined by the sum of the metric values of the input token metrics.

  • input tokens
  • cache read input tokens
  • cache write input tokens

Instance Attribute Summary collapse

Instance Attribute Details

#end_value::Integer (readonly)

Returns Output only. The exclusive upper bound of the range. If no end value is specified, the range is unbounded from above.

Returns:

  • (::Integer)

    Output only. The exclusive upper bound of the range. If no end value is specified, the range is unbounded from above.



546
547
548
549
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 546

class CombinedRequestInputTokensRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_value::Integer (readonly)

Returns Output only. The inclusive lower bound of the range.

Returns:

  • (::Integer)

    Output only. The inclusive lower bound of the range.



546
547
548
549
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 546

class CombinedRequestInputTokensRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end