Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformProvisionedThroughputFee

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Details about a SKU pricing reservation of AI Platform Provisioned Throughput.

Customers may purchase provisioned throughput reservations for AI Platform managed model products. This provides the customer with provisioned throughput quota for a particular model and location. Model usage below the provisioned throughput quota threshold is voided and is not charged by the product's managed model usage fees.

Instance Attribute Summary collapse

Instance Attribute Details

#gsu_price_per_unit::Google::Type::Money

Returns The price per Generative AI Scale Unit (GSU) per unit. A provisioned throughput reservation reserves a certain number of GSUs, and the customer is billed for those GSUs on a continuous basis for the duration of the reservation.

Returns:

  • (::Google::Type::Money)

    The price per Generative AI Scale Unit (GSU) per unit. A provisioned throughput reservation reserves a certain number of GSUs, and the customer is billed for those GSUs on a continuous basis for the duration of the reservation.



620
621
622
623
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 620

class AiPlatformProvisionedThroughputFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelEndpointLocation (readonly)

Returns Output only. The location where provisioned throughput is priced by this SKU.

Returns:



620
621
622
623
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 620

class AiPlatformProvisionedThroughputFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#term_duration_months::Integer (readonly)

Returns Output only. The duration of the provisioned throughput reservation in months.

Returns:

  • (::Integer)

    Output only. The duration of the provisioned throughput reservation in months.



620
621
622
623
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 620

class AiPlatformProvisionedThroughputFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unit::String (readonly)

Returns Output only. The price unit of the SKU. See https://ucum.org/ucum.html for the format of the price unit. Since provisioned throughput reservations are billed by duration, this will always be a time unit. The price unit of a provisioned throughput SKU is not necessarily the same as the reservation term. This field is unrelated to the Generative AI Scale Unit (GSU).

Currently the unit is always months ('mo'). Additional time units may be supported in future.

The customary unit month ('mo') requires special handling to account for the variable duration of months. A price may be denominated in units of months, but the duration the reservation is active is measured in metric time and customers are billed on that basis. The exact hourly or per-second price can be calculated by dividing the monthly price by the number of hours or seconds in the desired month. A reservation active for N months is rarely billed exactly N times the monthly price. This is intended and is not a billing error.

Returns:

  • (::String)

    Output only. The price unit of the SKU. See https://ucum.org/ucum.html for the format of the price unit. Since provisioned throughput reservations are billed by duration, this will always be a time unit. The price unit of a provisioned throughput SKU is not necessarily the same as the reservation term. This field is unrelated to the Generative AI Scale Unit (GSU).

    Currently the unit is always months ('mo'). Additional time units may be supported in future.

    The customary unit month ('mo') requires special handling to account for the variable duration of months. A price may be denominated in units of months, but the duration the reservation is active is measured in metric time and customers are billed on that basis. The exact hourly or per-second price can be calculated by dividing the monthly price by the number of hours or seconds in the desired month. A reservation active for N months is rarely billed exactly N times the monthly price. This is intended and is not a billing error.



620
621
622
623
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 620

class AiPlatformProvisionedThroughputFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end