Module: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::ComputeEngineLicenseUsageFee::MachineResource

Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

The machine resource type that the SKU applies to, if any.

Constant Summary collapse

MACHINE_RESOURCE_UNSPECIFIED =

The SKU applies to all instances irrespective of machine shape. This is referred to as "instance-based pricing" because the price is the same for all instances.

0
VCPU_COUNT =

The SKU applies based on the instance's vCPU count.

1
MEMORY_BYTES =

The SKU applies based on the instance's memory size in bytes.

2
GPU_COUNT =

The SKU applies based on the instance's GPU count.

3