Module: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::ComputeEngineLicenseUsageFee::UsageCalculation
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku.rb
Overview
Determines how the customer's usage is calculated.
Constant Summary collapse
- USAGE_CALCULATION_UNSPECIFIED =
Unused.
0- INSTANCE_RUNTIME =
Usage is calculated from instance runtime. The customer's usage is metered according to the Compute Engine VM instance pricing model, measured on a per-instance basis in units of hours, with a minimum duration of one minute and an increment of one second.
A SKU using this usage calculation is referred to as "flat" because the customer's usage charge is independent of the instance's machine resource shape apart from determining whether the SKU applies to the instance.
1- LINEAR_RESOURCE_SCALED_INSTANCE_RUNTIME =
Usage is calculated from instance runtime and size. This calculation mode is only applicable to resource-based SKUs. Usage is calculated by measuring the instance runtime in the same manner as for
INSTANCE_RUNTIMEand multiplying by the instance's machine resource value matching the SKU's machine resource type. This converts the price from per-instance-hour to per-instance-hour-per-machine-resource, which changes the price unit for memory SKUs to 'GiBy.h'. The price unit otherwise remains 'h' because the other machine resources are dimensionless.A SKU using this usage calculation is referred to as "linear" because the customer's usage charge is linearly proportional to the instance's machine resource value.
2