Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::KubernetesEnginePodUsageFee::PodResourceRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

The range of pod resource values that the SKU applies to.

Instance Attribute Summary collapse

Instance Attribute Details

#end_value::Integer (readonly)

Returns Output only. The exclusive upper bound of the range. If no end value is specified, the range is unbounded from above.

Returns:

  • (::Integer)

    Output only. The exclusive upper bound of the range. If no end value is specified, the range is unbounded from above.



356
357
358
359
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 356

class PodResourceRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_value::Integer (readonly)

Returns Output only. The inclusive lower bound of the range.

Returns:

  • (::Integer)

    Output only. The inclusive lower bound of the range.



356
357
358
359
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 356

class PodResourceRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end