Module: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::KubernetesEnginePodUsageFee::UsageCalculation

Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Determines how the customer's usage is calculated.

Constant Summary collapse

USAGE_CALCULATION_UNSPECIFIED =

Unused.

0
POD_RUNTIME =

Usage is calculated from pod runtime. The customer's usage is metered in a manner similar to the GKE Autopilot mode for pods without specific hardware requirements, priced on a per-pod basis in units of hours and measured in one-second increments, with no minimum duration.

A SKU using this usage calculation is referred to as "flat" because the customer's usage charge is independent of the pod shape apart from determining whether the SKU applies to the pod.

1
LINEAR_RESOURCE_SCALED_POD_RUNTIME =

Usage is calculated from pod runtime and size. This calculation mode is only applicable to resource-based SKUs. Usage is calculated by measuring the pod runtime in the same manner as for POD_RUNTIME and multiplying by the pod's resource value matching the SKU's pod resource type. This converts the price from per-pod-hour to per-pod-hour-per-resource, which changes the price unit for memory SKUs to 'GiBy.h'. The price unit otherwise remains 'h' because the other resources are dimensionless.

A SKU using this usage calculation is referred to as "linear" because the customer's usage charge is linearly proportional to the pod's resource value.

2