Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::ManagedServiceMetricUsageFee

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/sku.rb

Overview

Details about a SKU pricing usage of a partner-reported custom billing metric defined by the partner in the Service Management API and reported using the Service Control API.

The customer's usage charge is computed by converting the customer's reported consumption to the SKU's composite price unit and applying the graduated price from the appropriate price tier.

Instance Attribute Summary collapse

Instance Attribute Details

#canonical_metric::String (readonly)

Returns Output only. The name of the metric, in canonical format.

Note that in the canonical format the first character of the path component of the metric name is always uppercase, which may differ from the metric name in the service config. For example, a metric appearing in the service config as 'example.com/example_metric' will appear here in the SKU as 'example.com/Example_metric'. In the Service Management and Service Control APIs these two metric names are considered distinct, either or both may be defined, and usage must be reported using a name matching the name of a metric defined in the service config. But for billing purposes usage reported using either name will be aggregated under the canonical metric name.

Example: "example.com/Example_metric".

Returns:

  • (::String)

    Output only. The name of the metric, in canonical format.

    Note that in the canonical format the first character of the path component of the metric name is always uppercase, which may differ from the metric name in the service config. For example, a metric appearing in the service config as 'example.com/example_metric' will appear here in the SKU as 'example.com/Example_metric'. In the Service Management and Service Control APIs these two metric names are considered distinct, either or both may be defined, and usage must be reported using a name matching the name of a metric defined in the service config. But for billing purposes usage reported using either name will be aggregated under the canonical metric name.

    Example: "example.com/Example_metric"



164
165
166
167
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 164

class ManagedServiceMetricUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tiered_price::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::TieredPrice (readonly)

Returns Output only. Tiered pricing of the SKU.



164
165
166
167
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 164

class ManagedServiceMetricUsageFee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end