Class: Google::Cloud::CommerceProducer::V1beta::StandardOffer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb

Overview

Message describing the StandardOffer resource.

Defined Under Namespace

Classes: PriceModel

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation time of the offer.

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#effective_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Effective time of the offer. Prior to this time, the offer cannot be purchased or used as the base standard offer of a private offer.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Effective time of the offer. Prior to this time, the offer cannot be purchased or used as the base standard offer of a private offer.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#expire_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Expire time of the offer. An offer is expired if its expire time is in the past. An expired standard offer cannot be purchased or used as the base standard offer of a private offer.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Expire time of the offer. An offer is expired if its expire time is in the past. An expired standard offer cannot be purchased or used as the base standard offer of a private offer.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Name of resource.

Returns:

  • (::String)

    Identifier. Name of resource.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#price_model::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel (readonly)

Returns Output only. Price model of the offer.

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#service_level::String (readonly)

Returns Output only. Identifier that distinguishes between different service levels of the same product that constitute distinct offerings to customers with different pricing.

The service levels of a product are also referred to in some cases as the product's 'plans', and the service_level value is referred to in some cases as the "plan ID".

Multiple non-expired standard offers can share the same service level when they are subscription offers for different term durations.

Returns:

  • (::String)

    Output only. Identifier that distinguishes between different service levels of the same product that constitute distinct offerings to customers with different pricing.

    The service levels of a product are also referred to in some cases as the product's 'plans', and the service_level value is referred to in some cases as the "plan ID".

    Multiple non-expired standard offers can share the same service level when they are subscription offers for different term durations.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#service_level_title::String (readonly)

Returns Output only. Title of the service level.

Not included for STANDARD_OFFER_VIEW_BASIC.

Returns:

  • (::String)

    Output only. Title of the service level.

    Not included for STANDARD_OFFER_VIEW_BASIC.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#term_duration_months::Integer (readonly)

Returns Output only. Term duration of the offer in months. Applicable only to offers with a subscription price model. Additional forms of offer term may be added in the future.

Returns:

  • (::Integer)

    Output only. Term duration of the offer in months. Applicable only to offers with a subscription price model. Additional forms of offer term may be added in the future.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last update time of the offer.

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 70

class StandardOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Price model of the offer.
  # @!attribute [r] flat_fee
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription]
  #     Output only. Price configurations for the flat fee subscription.
  # @!attribute [r] usage
  #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage]
  #     Output only. Price configurations for the usage part.
  class PriceModel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # A collection of SKUs.
    # @!attribute [r] skus
    #   @return [::Array<::String>]
    #     Output only. List of SKUs by name.
    class SkuList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # A collection of SkuGroups.
    # @!attribute [r] sku_groups
    #   @return [::Array<::String>]
    #     Output only. List of SkuGroups by name.
    class SkuGroupList
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for the usage part.
    # @!attribute [r] sku_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList]
    #     Output only. The offer's usage fees are charged against these SKUs.
    #
    #     Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    # @!attribute [r] sku_group_list
    #   @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList]
    #     Output only. The offer's usage fees are charged against the SKUs in
    #     these groups.
    #
    #     Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared.
    class Usage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Price configurations for flat fee subscriptions.
    # @!attribute [r] sku
    #   @return [::String]
    #     Output only. Flat fee subscription SKU for the offer.
    class FlatFeeSubscription
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end