Class: Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb

Overview

Price configurations for the usage part.

Instance Attribute Summary collapse

Instance Attribute Details

#sku_group_list::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList (readonly)

Returns Output only. The offer's usage fees are charged against the SKUs in these groups.

Note: The following fields are mutually exclusive: sku_group_list, sku_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 115

class Usage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sku_list::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList (readonly)

Returns Output only. The offer's usage fees are charged against these SKUs.

Note: The following fields are mutually exclusive: sku_list, sku_group_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 115

class Usage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end