Class: Google::Cloud::CommerceProducer::V1beta::UpdatePrivateOfferRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb

Overview

Message for updating a PrivateOffer

Instance Attribute Summary collapse

Instance Attribute Details

#private_offer::Google::Cloud::CommerceProducer::V1beta::PrivateOffer

Returns Required. The resource being updated.

Returns:



169
170
171
172
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 169

class UpdatePrivateOfferRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. The special value "*" means full replacement. If unspecified, all fields present in the request will be overwritten.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. The list of fields to update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. The special value "*" means full replacement. If unspecified, all fields present in the request will be overwritten.



169
170
171
172
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 169

class UpdatePrivateOfferRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end