Class: Google::Cloud::CommerceProducer::V1beta::DeletePrivateOfferRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::DeletePrivateOfferRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for deleting a PrivateOffer
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. Indicates whether to cascade the delete to child resources. If false, the request fails if child resources exist.
207 208 209 210 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 207 class DeletePrivateOfferRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the resource.
207 208 209 210 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 207 class DeletePrivateOfferRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |