Class: Google::Cloud::CommerceProducer::V1beta::ListPrivateOffersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::ListPrivateOffersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for response to listing PrivateOffers
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#private_offers ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::PrivateOffer>
The list of PrivateOffer.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
68 69 70 71 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 68 class ListPrivateOffersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_offers ⇒ ::Array<::Google::Cloud::CommerceProducer::V1beta::PrivateOffer>
Returns The list of PrivateOffer.
68 69 70 71 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 68 class ListPrivateOffersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |