Class: Google::Cloud::CommerceProducer::V1beta::ListSkusRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::ListSkusRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for requesting list of Skus
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. Maximum results to return. The service may return fewer than this value. The maximum value is 500; values above 500 will be coerced to 500. If unspecified, the server will default to the maximum.
416 417 418 419 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 416 class ListSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous list response message. Provide this to retrieve the subsequent page.
When paginating, all other parameters of the list request must match the request that returned the page token.
416 417 418 419 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 416 class ListSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for ListSkusRequest.
416 417 418 419 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 416 class ListSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |