Class: Google::Cloud::CommerceProducer::V1beta::PrivateOffer::Customer
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::PrivateOffer::Customer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb
Overview
Information about the customer.
Instance Attribute Summary collapse
-
#address ⇒ ::String
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#contact ⇒ ::String
Optional.
-
#email ⇒ ::String
Optional.
-
#entity_title ⇒ ::String
Optional.
-
#target_billing_account ⇒ ::String
Optional.
Instance Attribute Details
#address ⇒ ::String (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. Legal address of the customer organization. This field can no longer be set, but it is preserved to return the data from existing offers where address is set.
231 232 233 234 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 231 class Customer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#contact ⇒ ::String
Returns Optional. A string identifying the customer contact. Must be provided when publishing the offer. Maximum length: 256 characters.
231 232 233 234 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 231 class Customer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#email ⇒ ::String
Returns Optional. Email of customer contact. If provided, it must be a well-formed email address.
231 232 233 234 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 231 class Customer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entity_title ⇒ ::String
Returns Optional. A string identifying the customer's entity (for example, the customer's organization or company name). Must be provided when publishing the offer. Maximum length: 256 characters.
231 232 233 234 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 231 class Customer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_billing_account ⇒ ::String
Returns Optional. The customer's billing account targeted by the offer. The private offer once published can be accepted by a billing administrator of the target billing account. If the customer accepts the offer and later moves the resulting order to a new billing account, this field will continue to reflect the original billing account to which the private offer was extended. Must be provided when publishing the offer.
To publish this private offer:
- The billing account must exist.
- The billing account must not be in a free trial.
- The billing account must comply with Marketplace Reselling Policies.
- Reseller parent billing accounts are prohibited. Reseller subaccounts are prohibited unless the service is enabled for reselling.
Format: billingAccounts/012345-567890-ABCDEF.
231 232 233 234 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 231 class Customer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |