Class: Google::Cloud::CommerceProducer::V1beta::PrivateOffer::ResellerContact
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::PrivateOffer::ResellerContact
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb
Overview
Contact information for a reseller.
Instance Attribute Summary collapse
-
#contact ⇒ ::String
readonly
Output only.
-
#email ⇒ ::String
readonly
Output only.
Instance Attribute Details
#contact ⇒ ::String (readonly)
Returns Output only. The name of the reseller contact for this offer.
168 169 170 171 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 168 class ResellerContact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#email ⇒ ::String (readonly)
Returns Output only. The email of the reseller contact for this offer.
168 169 170 171 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/private_offer.rb', line 168 class ResellerContact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |