Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku.rb
Overview
The usage metric that the SKU applies to.
Defined Under Namespace
Classes: CacheReadInputTokensMetric, CacheWriteInputTokensMetric, InputTokensMetric, OutputTokensMetric, WebSearchRequestsMetric
Instance Attribute Summary collapse
-
#cache_read_input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric
readonly
Output only.
-
#cache_write_input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric
readonly
Output only.
-
#input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric
readonly
Output only.
-
#output_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric
readonly
Output only.
-
#web_search_requests_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric
readonly
Output only.
Instance Attribute Details
#cache_read_input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheReadInputTokensMetric (readonly)
Returns Output only. Input tokens read from the cache.
Note: The following fields are mutually exclusive: cache_read_input_tokens_metric, input_tokens_metric, cache_write_input_tokens_metric, output_tokens_metric, web_search_requests_metric. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 488 class AiPlatformManagedModelUsageMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input tokens read from the input to the prediction endpoint. # The unit for this metric is dimensionless. class InputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens read from the cache. # The unit for this metric is dimensionless. class CacheReadInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens written to the cache. # The unit for this metric is dimensionless. # @!attribute [r] ttl # @return [::Google::Protobuf::Duration] # Output only. The duration the write is retained in the cache. class CacheWriteInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output tokens returned from the prediction endpoint. # The unit for this metric is dimensionless. class OutputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Web search requests executed by the model. # The unit for this metric is dimensionless. class WebSearchRequestsMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#cache_write_input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::CacheWriteInputTokensMetric (readonly)
Returns Output only. Input tokens written to the cache.
Note: The following fields are mutually exclusive: cache_write_input_tokens_metric, input_tokens_metric, cache_read_input_tokens_metric, output_tokens_metric, web_search_requests_metric. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 488 class AiPlatformManagedModelUsageMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input tokens read from the input to the prediction endpoint. # The unit for this metric is dimensionless. class InputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens read from the cache. # The unit for this metric is dimensionless. class CacheReadInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens written to the cache. # The unit for this metric is dimensionless. # @!attribute [r] ttl # @return [::Google::Protobuf::Duration] # Output only. The duration the write is retained in the cache. class CacheWriteInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output tokens returned from the prediction endpoint. # The unit for this metric is dimensionless. class OutputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Web search requests executed by the model. # The unit for this metric is dimensionless. class WebSearchRequestsMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::InputTokensMetric (readonly)
Returns Output only. Input tokens read from the prediction endpoint input.
Note: The following fields are mutually exclusive: input_tokens_metric, cache_read_input_tokens_metric, cache_write_input_tokens_metric, output_tokens_metric, web_search_requests_metric. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 488 class AiPlatformManagedModelUsageMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input tokens read from the input to the prediction endpoint. # The unit for this metric is dimensionless. class InputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens read from the cache. # The unit for this metric is dimensionless. class CacheReadInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens written to the cache. # The unit for this metric is dimensionless. # @!attribute [r] ttl # @return [::Google::Protobuf::Duration] # Output only. The duration the write is retained in the cache. class CacheWriteInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output tokens returned from the prediction endpoint. # The unit for this metric is dimensionless. class OutputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Web search requests executed by the model. # The unit for this metric is dimensionless. class WebSearchRequestsMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#output_tokens_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::OutputTokensMetric (readonly)
Returns Output only. Output tokens returned from the prediction endpoint.
Note: The following fields are mutually exclusive: output_tokens_metric, input_tokens_metric, cache_read_input_tokens_metric, cache_write_input_tokens_metric, web_search_requests_metric. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 488 class AiPlatformManagedModelUsageMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input tokens read from the input to the prediction endpoint. # The unit for this metric is dimensionless. class InputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens read from the cache. # The unit for this metric is dimensionless. class CacheReadInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens written to the cache. # The unit for this metric is dimensionless. # @!attribute [r] ttl # @return [::Google::Protobuf::Duration] # Output only. The duration the write is retained in the cache. class CacheWriteInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output tokens returned from the prediction endpoint. # The unit for this metric is dimensionless. class OutputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Web search requests executed by the model. # The unit for this metric is dimensionless. class WebSearchRequestsMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#web_search_requests_metric ⇒ ::Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::AiPlatformManagedModelUsageFee::AiPlatformManagedModelUsageMetric::WebSearchRequestsMetric (readonly)
Returns Output only. Web search requests executed by the model.
Note: The following fields are mutually exclusive: web_search_requests_metric, input_tokens_metric, cache_read_input_tokens_metric, cache_write_input_tokens_metric, output_tokens_metric. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 488 class AiPlatformManagedModelUsageMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input tokens read from the input to the prediction endpoint. # The unit for this metric is dimensionless. class InputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens read from the cache. # The unit for this metric is dimensionless. class CacheReadInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Input tokens written to the cache. # The unit for this metric is dimensionless. # @!attribute [r] ttl # @return [::Google::Protobuf::Duration] # Output only. The duration the write is retained in the cache. class CacheWriteInputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output tokens returned from the prediction endpoint. # The unit for this metric is dimensionless. class OutputTokensMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Web search requests executed by the model. # The unit for this metric is dimensionless. class WebSearchRequestsMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |