Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::ComputeEngineLicenseUsageFee::MachineResourceRange
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::ComputeEngineLicenseUsageFee::MachineResourceRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku.rb
Overview
The range of machine resource values that the SKU applies to.
Instance Attribute Summary collapse
-
#end_value ⇒ ::Integer
readonly
Output only.
-
#start_value ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#end_value ⇒ ::Integer (readonly)
Returns Output only. The exclusive upper bound of the range. If no end value is specified, the range is unbounded from above.
242 243 244 245 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 242 class MachineResourceRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_value ⇒ ::Integer (readonly)
Returns Output only. The inclusive lower bound of the range. While the number zero may be the start of a range, it is not a possible machine resource value. An instance cannot exist with zero vCPU or memory, and an instance with no attached accelerators lacks a GPU dimension entirely rather than having a GPU count of zero.
242 243 244 245 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 242 class MachineResourceRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |