Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::FlatSubscriptionFee
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::FlatSubscriptionFee
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku.rb
Overview
Details about a SKU charging a flat subscription fee.
Instance Attribute Summary collapse
-
#price_per_unit ⇒ ::Google::Type::Money
readonly
Output only.
-
#unit ⇒ ::String
readonly
Output only.
Instance Attribute Details
#price_per_unit ⇒ ::Google::Type::Money (readonly)
Returns Output only. The price per time unit the subscription is active.
691 692 693 694 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 691 class FlatSubscriptionFee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unit ⇒ ::String (readonly)
Returns Output only. The unit of the subscription SKU. See https://ucum.org/ucum.html for the format of the price unit. Since subscriptions are billed by duration, this will always be a time unit. The price unit of a subscription SKU is not necessarily the same as the subscription period of the corresponding StandardOffers.
Currently the unit is always months ('mo'). Additional time units may be supported in future.
The unit month ('mo') is a customary time unit and requires special handling to account for the variable duration of months. A price may be denominated in units of months, but the duration the subscription is active is measured in metric time and customers are billed on that basis. The exact hourly or per-second price can be calculated by dividing the monthly price by the number of hours or seconds in the desired month. A subscription active for N months is rarely billed exactly N times the monthly price. This is intended and is not a billing error.
691 692 693 694 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 691 class FlatSubscriptionFee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |