Class: Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::TieredPrice::PriceTier
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::Sku::SkuPrice::TieredPrice::PriceTier
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku.rb
Overview
A price tier pricing metric usage within a range.
Each marginal unit of usage is priced according to the price tier in which it falls.
Instance Attribute Summary collapse
-
#price ⇒ ::Google::Type::Money
readonly
Output only.
-
#start_amount ⇒ ::Google::Type::Decimal
readonly
Output only.
Instance Attribute Details
#price ⇒ ::Google::Type::Money (readonly)
Returns Output only. The price per price_unit_count of unit in the tier.
The price is applied fractionally if the customer's usage within the
tier is not an integer multiple of price_unit_count.
759 760 761 762 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 759 class PriceTier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_amount ⇒ ::Google::Type::Decimal (readonly)
Returns Output only. Inclusive lower bound of the tier interval, denominated
in unit.
759 760 761 762 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku.rb', line 759 class PriceTier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |