Class: Google::Cloud::CommerceProducer::V1beta::SkuGroup
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::SkuGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/sku_group.rb
Overview
Message describing SkuGroup resource
Instance Attribute Summary collapse
-
#cloud_billing_skus ⇒ ::Array<::String>
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#skus ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#cloud_billing_skus ⇒ ::Array<::String> (readonly)
Returns Output only. Google SKUs included in the SkuGroup.
Used for partner products sold by Google, such as Premium Operating System Images sold for use in Compute Engine. This is not common. SKUs of this type are not present on this API and can instead be found on the Cloud Billing API or at https://cloud.google.com/skus.
Format: services/{service}/skus/{sku}.
43 44 45 46 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku_group.rb', line 43 class SkuGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. Identifier. Name of the SkuGroup.
43 44 45 46 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku_group.rb', line 43 class SkuGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skus ⇒ ::Array<::String> (readonly)
Returns Output only. Partner SKUs included in the SkuGroup.
Format:
projects/{project}/locations/{location}/services/{service}/skus/{sku}.
43 44 45 46 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/sku_group.rb', line 43 class SkuGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |