Class: Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb
Overview
Price model of the offer.
Defined Under Namespace
Classes: FlatFeeSubscription, SkuGroupList, SkuList, Usage
Instance Attribute Summary collapse
-
#flat_fee ⇒ ::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription
readonly
Output only.
-
#usage ⇒ ::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage
readonly
Output only.
Instance Attribute Details
#flat_fee ⇒ ::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::FlatFeeSubscription (readonly)
Returns Output only. Price configurations for the flat fee subscription.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 81 class PriceModel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection of SKUs. # @!attribute [r] skus # @return [::Array<::String>] # Output only. List of SKUs by name. class SkuList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A collection of SkuGroups. # @!attribute [r] sku_groups # @return [::Array<::String>] # Output only. List of SkuGroups by name. class SkuGroupList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Price configurations for the usage part. # @!attribute [r] sku_list # @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList] # Output only. The offer's usage fees are charged against these SKUs. # # Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] sku_group_list # @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList] # Output only. The offer's usage fees are charged against the SKUs in # these groups. # # Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Usage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Price configurations for flat fee subscriptions. # @!attribute [r] sku # @return [::String] # Output only. Flat fee subscription SKU for the offer. class FlatFeeSubscription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#usage ⇒ ::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::Usage (readonly)
Returns Output only. Price configurations for the usage part.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/standard_offer.rb', line 81 class PriceModel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection of SKUs. # @!attribute [r] skus # @return [::Array<::String>] # Output only. List of SKUs by name. class SkuList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A collection of SkuGroups. # @!attribute [r] sku_groups # @return [::Array<::String>] # Output only. List of SkuGroups by name. class SkuGroupList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Price configurations for the usage part. # @!attribute [r] sku_list # @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuList] # Output only. The offer's usage fees are charged against these SKUs. # # Note: The following fields are mutually exclusive: `sku_list`, `sku_group_list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] sku_group_list # @return [::Google::Cloud::CommerceProducer::V1beta::StandardOffer::PriceModel::SkuGroupList] # Output only. The offer's usage fees are charged against the SKUs in # these groups. # # Note: The following fields are mutually exclusive: `sku_group_list`, `sku_list`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Usage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Price configurations for flat fee subscriptions. # @!attribute [r] sku # @return [::String] # Output only. Flat fee subscription SKU for the offer. class FlatFeeSubscription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |