Class: Google::Cloud::CommerceProducer::V1beta::UpdatePrivateOfferDocumentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CommerceProducer::V1beta::UpdatePrivateOfferDocumentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb
Overview
Message for updating a PrivateOfferDocument
Instance Attribute Summary collapse
-
#private_offer_document ⇒ ::Google::Cloud::CommerceProducer::V1beta::PrivateOfferDocument
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#private_offer_document ⇒ ::Google::Cloud::CommerceProducer::V1beta::PrivateOfferDocument
Returns Required. The resource being updated.
278 279 280 281 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 278 class UpdatePrivateOfferDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields to update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. The special value "*" means full replacement. If unspecified, all fields present in the request will be overwritten.
278 279 280 281 |
# File 'proto_docs/google/cloud/commerceproducer/v1beta/commerce_transaction.rb', line 278 class UpdatePrivateOfferDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |